@@ -50,7 +50,7 @@ logRegMultiClass <- R6::R6Class(
         #### Compute results ----
         .compute = function(data) {
 
-            formulas <- private$.formula()
+            formulas <- private$.formulas()
 
             globalContr <- options('contrasts')$contrasts
             options('contrasts' = c('contr.treatment', 'contr.poly'))
@@ -744,7 +744,7 @@ logRegMultiClass <- R6::R6Class(
 
             return(list(coefNames=coefNames, coefTerms=coefTerms))
         },
-        .formula = function() {
+        .formulas = function() {
 
             dep <- self$options$dep
             depB64 <- jmvcore::toB64(dep)
